@@ -8,8 +8,6 @@ use Fennec::Util::Accessors;
 
 Accessors qw/intercepted/;
 
-sub cull {}
-
 sub init {
     my $self = shift;
     $self->intercepted([]);
@@ -23,6 +21,29 @@ sub write {
 
 1;
 
+=head1 NAME
+
+Fennec::Collector::Interceptor - Intercept output objects instead fo sending
+them to parent.
+
+=head1 METHODS
+
+=over 4
+
+=item $results = $obj->intercepted()
+
+Return an array of result objects written.
+
+=item $obj->write( $output )
+
+Write an output object.
+
+=item $obj->init()
+
+Used internally, will destroy any stored output objects if called.
+
+=back
+
 =head1 AUTHORS
 
 Chad Granum L<exodist7@gmail.com>
