@@ -2,23 +2,11 @@ package Fennec::FileLoader;
 use strict;
 use warnings;
 
-use Carp;
-use Fennec::Output::Result;
-use Fennec::Util::Abstract;
 require Fennec;
-
-use List::MoreUtils qw/uniq/;
 use Cwd qw/cwd/;
-use File::Find qw/find/;
-BEGIN {
-    *_find = \&find;
-    undef( *Fennec::FileLoader::find );
-}
 
 our $ROOT;
 
-Abstract qw/ valid_file load_file paths /;
-
 sub root {
     my $class = shift;
     unless ( $ROOT ) {
@@ -48,24 +36,16 @@ sub _looks_like_root {
 sub find_types {
     my $class = shift;
     my ( $types, $files ) = @_;
-    my @paths;
 
     my @plugins;
     for my $type ( @$types ) {
-        my $plugin = "Fennec\::FileLoader\::$type";
+        my $plugin = "Fennec\::FileType\::$type";
         eval "require $plugin" || die( $@ );
         push @plugins => $plugin;
-        push @paths => $plugin->paths;
     }
-    @paths = uniq @paths;
 
-    unless ( $files ) {
-        $files = [];
-        _find(
-            sub { push @$files => $File::Find::name },
-            map { $class->root . "/$_" } @paths
-        );
-    }
+    return $class->find_all( @plugins )
+        unless $files;
 
     my @out;
     for my $file ( @$files ) {
@@ -80,59 +60,50 @@ sub find_types {
     return @out;
 }
 
-sub find {
+sub find_all {
     my $class = shift;
-    my @list;
-    _find(
-        sub {
-            my $file = $File::Find::name;
-            return unless $class->valid_file( $file );
-            push @list => $file;
-        },
-        map { $class->root . "/$_" } $class->paths
-    ) if $class->paths;
-
-    return map { $class->new( $_ ) } @list;
-}
-
-sub new {
-    my $class = shift;
-    my ( $file ) = @_;
-
-    croak( "$class\::new() called without a filename" )
-        unless $file;
-    croak( "$file is not a valid $class file" )
-        unless $class->valid_file( $file );
-
-    return bless( [ $file, 0 ], $class );
-}
-
-sub data {
-    my $self = shift;
-    ( $self->[2] ) = @_ if @_;
-    return $self->[2];
-}
-
-sub load {
-    my $self = shift;
-    return 1 if $self->[1]++;
-    Fennec->_clear_test_class;
-
-    $self->load_file( $self->[0] );
-
-    my $tclass = Fennec->_test_class;
-    croak( "loading '" . $self->[0] . "' did not produce a test class" )
-        unless $tclass;
-    return $tclass;
-}
-
-sub filename {
-    my $self = shift;
-    $self->[0];
+    my @plugins = @_;
+    my @out;
+    for my $plugin ( @plugins ) {
+        push @out => $plugin->find();
+    }
+    return @out;
 }
 
 1;
 
+=head1 NAME
+
+Fennec::FileLoader - Utility to find and load Fennec tests
+
+=head1 DESCRIPTION
+
+This class is responsible for loading the FileType modules, and finding/loading
+Fennec test files.
+
+=head1 CLASS METHODS
+
+=over 4
+
+=item my $root = $class->root()
+
+Return the project root directory.
+
+=item @files = @find_types( \@types )
+
+=item @files = find_types( \@types, \@files )
+
+Takes a list of types (Last part of package name only) and optionally a list of
+files. Returns an array of FileType objects each constructed with a single
+filename.
+
+=item @files = find_all( @type_classes )
+
+Returns a list of FileType objects for all the classes specified. Takes full
+class names.
+
+=back
+
 =head1 AUTHORS
 
 Chad Granum L<exodist7@gmail.com>
